var gphoto2_result_8c =
[
    [ "_", "gphoto2-result_8c.html#a32a3cf3d9dd914f5aeeca5423c157934", null ],
    [ "N_", "gphoto2-result_8c.html#a75278405e7f034d2b1af80bfd94675fe", null ],
    [ "gp_result_as_string", "gphoto2-result_8c.html#aeedb403d0eb07560182191c551dc5178", null ],
    [ "description", "gphoto2-result_8c.html#a68344fa88cf4e86b5079fd69a5c22d57", null ],
    [ "result", "gphoto2-result_8c.html#a8b2e13c78efca330f06b6ddcd7464b41", null ]
];